%Load relevant inputs
load('env2004-2018.mat')
load('morphology_data.mat');

%Build morphology grid
morph_input = combinedmorph4.line55;
morph_end = combinedmorph18.line55;
scenario.grids.morphometrics.backshoreslope = 0.1;
scenario.grids.morphometrics.zshore = 1.5;
scenario.grids.morphometrics.dx = 0.1;
scenario.grids.morphometrics.dtoe =  3.5;
scenario.grids.morphometrics.duneslope = 10;
scenario.grids.XGrid = 0:scenario.grids.morphometrics.dx:max(morph_input.dist);
scenario.grids.ZGrid = interp1(morph_input.dist, morph_input.zcorr, scenario.grids.XGrid);

%Define Free Parameters 
scenario.grids.morphometrics.shorechange = -1.8; %shoreline change rate in m/yr
scenario.models.WaveRunupFactor = 1.26; %scale factor for the runup component of total water levels
scenario.models.DuneSlopeTrajectory = 0.00001; %slope of the tundra toe trajectory
scenario.models.DuneErodibility = 0.011; %sediment erodibility coefficient for the tundra under collisional impacts

%Fix any bad environmental and topographic inputs
ibad = find(env.mwd > 90 & env.mwd < 270);
env.hs(ibad) = 0;
env.hs(isnan(env.hs) == 1) = 0;
env.tp(isnan(env.tp) == 1) = 2;
ibad = find(isnan(scenario.grids.ZGrid) == 1);
scenario.grids.ZGrid(ibad) = -2;

%Build Correct Structure for Environmental Inputs
scenario.env.waves.times = env.times;        
for it = 1:numel(env.hs)
    [scenario.env.waves.Hs_25m(it),scenario.env.waves.L_25m(it),alpha1] = shoal_waves(env.hs(it),37,0,env.tp(it),25);
end
scenario.env.waves.Tp = env.tp;
scenario.timing.times = env.times;
scenario.env.tides.wl = env.swl;

%Run model
scenario = pthpe_coastal_erosion_model(scenario);

%Plot Model Outputs
figure, 
hold on
plot(scenario.grids.XGrid, scenario.grids.ZGrid, 'k', 'LineWidth', 3)
plot(morph_end.dist, morph_end.zcorr, '-', 'LineWidth', 3, 'Color', [0.5 0.5 0.5])
plot(scenario.grids.XGrid, scenario.erosion.Z(:,end), 'LineWidth', 3, 'Color', [0.8 0.2 0.2])
legend('Lidar Topography - 2004','Lidar Topography - 2018', 'Model Simulation - 2018', 'Location', 'NorthWest')
grid on
xlabel('Cross-Shore Distance (m)')
ylabel('Elevation (m, NAVD)')
ylim([1.55 7])
       